@@ -1,11 +1,11 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from typing import List
 
-from availsim4core.src.context.context import Context
 from availsim4core.src.context.system.component_tree.component import Component
 from availsim4core.src.context.system.component_tree.status import Status
+from availsim4core.src.context.context import Context
 
 
 class ChildrenLogic:
@@ -14,7 +14,7 @@ class ChildrenLogic:
     """
 
     def __repr__(self):
-        return f"Not defined"
+        return "Not defined"
 
     def evaluate(self, list_of_children: List[Component], context: Context) -> Status:
         """
@@ -23,4 +23,3 @@ class ChildrenLogic:
         :param context: the context of the simulation (structure containing almost everything)
         :return: The Status of the evaluated node.
         """
-        pass
