@@ -1,10 +1,18 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
+
+"""
+Module for Failure class
+"""
 
 from enum import Enum
 
 
 class FailureType(Enum):
+    """
+    Enumerative-style class for two types of a failure
+    """
+
     DETECTABLE = "DETECTABLE"
     BLIND = "BLIND"
 
@@ -16,7 +24,11 @@ class FailureType(Enum):
 
 
 class Failure:
-    __slots__ = 'type_of_failure'
+    """
+    Objects of this class represent failures
+    """
+
+    __slots__ = ['type_of_failure']
 
     def __init__(self, type_of_failure: FailureType):
         self.type_of_failure = type_of_failure
@@ -25,4 +37,4 @@ class Failure:
         return f"Failure: {self.type_of_failure}"
 
     def __eq__(self,other):
-        return self.type_of_failure == other.type_of_failure
\ No newline at end of file
+        return self.type_of_failure == other.type_of_failure
