@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from availsim4core.src.context.system.probability_law.probability_law import ProbabilityLaw
 
@@ -20,14 +20,14 @@ class DeterministicLaw(ProbabilityLaw):
             return NotImplemented
         return super().__eq__(other)
 
-    def get_random_value(self):
+    def get_random_value(self) -> float:
         return self.parameters[0]
 
-    def get_quantile_value(self, quantile):
+    def get_quantile_value(self, quantile: float) -> float:
         return self.parameters[0]
 
-    def get_mean_value(self):
+    def get_mean_value(self) -> float:
         return self.parameters[0]
 
-    def get_variance_value(self):
+    def get_variance_value(self) -> float:
         return 0.0
