@@ -1,8 +1,7 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 import numpy
-from numpy.random import normal
 from scipy.special import erfinv
 
 from availsim4core.src.context.system.probability_law.probability_law import ProbabilityLaw
@@ -25,14 +24,14 @@ class NormalLaw(ProbabilityLaw):
         return super().__eq__(other)
 
     def get_random_value(self):
-        return normal(self.parameters[0], self.parameters[1])
+        return self.random_number_generator.normal(self.parameters[0], self.parameters[1])
 
-    def get_quantile_value(self, quantile):
+    def get_quantile_value(self, quantile: float) -> float:
         # https://en.wikipedia.org/wiki/Normal_distribution
         return self.parameters[0] + self.parameters[1] * numpy.sqrt(2) * erfinv(2 * quantile - 1)
 
-    def get_mean_value(self):
+    def get_mean_value(self) -> float:
         return self.parameters[0]
 
-    def get_variance_value(self):
+    def get_variance_value(self) -> float:
         return self.parameters[0] ** 2
