@@ -1,22 +1,21 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from availsim4core.src.context.context import Context
+from availsim4core.src.discrete_event_simulation.event.c_event.c_event import CEvent, CEventPriority
+
 if TYPE_CHECKING:
     from availsim4core.src.context.system.component_tree.basic import Component
 
-from availsim4core.src.context.context import Context
-from availsim4core.src.discrete_event_simulation.event.c_event.c_event import CEvent
-
-
 class ComponentCEvent(CEvent):
     __slots__ = 'component'
 
     def __init__(self,
-                 priority: int,
+                 priority: CEventPriority,
                  context: Context,
                  component: Component):
         super().__init__(priority, context)
