@@ -1,8 +1,8 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from availsim4core.src.context.context import Context
-from availsim4core.src.discrete_event_simulation.event.c_event.c_event import CEvent
+from availsim4core.src.discrete_event_simulation.event.c_event.c_event import CEvent, CEventPriority
 
 
 class OrderNextPhaseEvent(CEvent):
@@ -11,7 +11,7 @@ class OrderNextPhaseEvent(CEvent):
     """
 
     def __init__(self,
-                 priority: int,
+                 priority: CEventPriority,
                  context: Context):
         super().__init__(priority, context)
 
