@@ -1,5 +1,9 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
+
+"""
+Module for the Event class
+"""
 
 from availsim4core.src.context.context import Context
 
@@ -10,8 +14,8 @@ class Event:
     event are processed in the Discrete event simulation algorithm.
     Events are immutable objects.
     """
-    __slots__ = 'context'
+    __slots__ = ['context']
 
     def __init__(self,
                  context: Context):
-        self.context = context
\ No newline at end of file
+        self.context = context
