@@ -1,16 +1,10 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from typing import List
 
 from availsim4core.src.context.context import Context
-from availsim4core.src.results.results import Results
-
-
-class SimulationType:
-    MONTE_CARLO = "MONTE_CARLO"
-    QUASI_MONTE_CARLO = "QUASI_MONTE_CARLO"
-    SPLITTING_MONTE_CARLO = "SPLITTING_MONTE_CARLO"
+from availsim4core.src.results.simulation_results import SimulationResults
 
 
 class Simulation:
@@ -19,7 +13,10 @@ class Simulation:
     When a simulation is ran, it returns a ResultSimulation.
     """
 
-    def run(self, context: Context) -> Results:
+    def __init__(self, maximum_execution_time: float) -> None:
+        self.maximum_execution_time = maximum_execution_time
+
+    def run(self, context: Context) -> SimulationResults:
         """
         Run a simulation against a given Component tree by calling multiple Discrete event Simulations.
         """
