@@ -1,7 +1,8 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 from availsim4core.src.context.phase.phase import Phase
+from availsim4core.src.context.system.rca_trigger import RootCauseAnalysisTrigger
 from availsim4core.src.results.result_record_entry_phase import ResultRecordEntryPhase
 from availsim4core.src.timeline.record import Record
 
@@ -29,5 +30,12 @@ class RecordPhase(Record):
     def __str__(self):
         return f"RecordPhase at {self.timestamp}: {self.phase.name}"
 
+    def get_name(self) -> str:
+        return self.phase.name
+
     def get_result_record_entry(self):
         return ResultRecordEntryPhase(self.phase, self.description)
+
+    def triggers_rca(self, rca_triggers):
+        return RootCauseAnalysisTrigger("PHASE", "_", self.phase.name) \
+            in rca_triggers
