@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 import glob
 import os
@@ -18,6 +18,9 @@ class test_E2E_phases(unittest.TestCase):
     ###
     # one failure occurs after a given deterministic time which is smaller than the duration of the simulation but still
     # the failure never occurs because the system does not spend enough time in that phase
+    SIMULATION_FILEPATH = "./availsim4core/test/E2E/input/phases/simulation.xlsx"
+
+
     expected_result_scenario_1 = [Result(11, "A2_0_11", "A", "RUNNING", "_MEAN_OCCURRENCES"),
                                   Result(0, "A2_0_11", "A", "FAILED", "_MEAN_OCCURRENCES"),
                                   Result(11, "Phase", "A", "_", "_MEAN_OCCURRENCES")]
@@ -25,7 +28,7 @@ class test_E2E_phases(unittest.TestCase):
                            "A1_0_9", "A1_1_10", "A2_0_11", "C3_0_12"]:
         expected_result_scenario_1.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_1 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/no_sufficient_time_in_faulty_phase_system.xlsx",
          None,
          1,
@@ -39,7 +42,7 @@ class test_E2E_phases(unittest.TestCase):
                            "A1_0_9", "A1_1_10", "A2_0_11", "C3_0_12"]:
         expected_result_scenario_2.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_2 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/sufficient_time_in_faulty_phase_system.xlsx",
          None,
          1,
@@ -54,7 +57,7 @@ class test_E2E_phases(unittest.TestCase):
                            "A1_0_9", "A1_1_10", "A2_0_11", "C3_0_12"]:
         expected_result_scenario_2b.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_2b = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/sufficient_time_in_faulty_phase_v2_system.xlsx",
          None,
          1,
@@ -69,7 +72,7 @@ class test_E2E_phases(unittest.TestCase):
                            "A1_0_9", "A1_1_10", "A2_0_11", "C3_0_12"]:
         expected_result_scenario_3.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_3 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/never_passing_in_faulty_phase_system.xlsx",
          None,
          1,
@@ -83,7 +86,7 @@ class test_E2E_phases(unittest.TestCase):
                            "A1_0_9", "A1_1_10", "A2_0_11", "C3_0_12"]:
         expected_result_scenario_4.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_4 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/passing_once_in_faulty_phase_system.xlsx",
          None,
          1,
@@ -108,7 +111,7 @@ class test_E2E_phases(unittest.TestCase):
         expected_result_scenario_5.append(Result(1, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
 
     scenario_5 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version1_no_phase_system.xlsx",
          None,
          1,
@@ -134,7 +137,7 @@ class test_E2E_phases(unittest.TestCase):
     # TODO: DETERMINISTIC CHECK
 
     scenario_6 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version2_failure_in_each_phase_system.xlsx",
          None,
          1,
@@ -160,7 +163,7 @@ class test_E2E_phases(unittest.TestCase):
     #    expected_result_scenario_6.append(Result(100, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
     # TODO: DETERMINISTIC CHECK
     scenario_6b = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version2_failure_in_each_phase_v2_system.xlsx",
          None,
          1,
@@ -186,7 +189,7 @@ class test_E2E_phases(unittest.TestCase):
     #    expected_result_scenario_6c.append(Result(100, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
     # TODO: DETERMINISTIC CHECK
     scenario_6c = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version2_failure_in_each_phase_v3_system.xlsx",
          None,
          1,
@@ -205,7 +208,7 @@ class test_E2E_phases(unittest.TestCase):
                            "E_0_10", "BFM12_0_11", "BFM34_0_12", "C_0_13"]:
         expected_result_scenario_7.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_7 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version3_failure_in_each_phase_2_failure_modes_system.xlsx",
          None,
          1,
@@ -224,7 +227,7 @@ class test_E2E_phases(unittest.TestCase):
                            "E_0_10", "BFM12_0_11", "BFM34_0_12", "C_0_13"]:
         expected_result_scenario_7b.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_7b = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version3_failure_in_each_phase_2_failure_modes_v2_system.xlsx",
          None,
          1,
@@ -243,7 +246,7 @@ class test_E2E_phases(unittest.TestCase):
                            "B_0_11", "C_0_12"]:
         expected_result_scenario_8.append(Result(100, component_name, "*", "*", "_MEAN_DURATION"))
     scenario_8 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/failure_in_each_Phase_but_change_phase_before_failure_system.xlsx",
          None,
          1,
@@ -268,7 +271,7 @@ class test_E2E_phases(unittest.TestCase):
         for phase, value in dict_of_phase_duration.items():
             expected_result_scenario_9.append(Result(value, component_name, phase, "*", "_MEAN_DURATION", tolerance=6))
     scenario_9 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version4_phases_but_no_failures_system.xlsx",
          None,
          1,
@@ -289,7 +292,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(30, "Phase", "CYCLING", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_10 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version5_phase_specific_to_failure_mode_system.xlsx",
          None,
          1,
@@ -313,7 +316,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(30, "Phase", "CYCLING", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_10b = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version5_phaseSpecificToFailureMode_parallelFault1_system.xlsx",
          None,
          1,
@@ -339,7 +342,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(0, "Phase", "CYCLING", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_10c = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version5_phaseSpecificToFailureMode_parallelFault2_system.xlsx",
          None,
          1,
@@ -362,7 +365,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(30, "Phase", "CYCLING", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_10d = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version5_phaseSpecificToFailureMode_parallelFault3_system.xlsx",
          None,
          1,
@@ -385,7 +388,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(30, "Phase", "CYCLING", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_10e = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version5_phaseSpecificToFailureMode_parallelFault4_system.xlsx",
          None,
          1,
@@ -402,7 +405,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(0, "Phase", "P2", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_11a = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/option_on_timing__after_repair__system.xlsx",
          None,
          1,
@@ -419,7 +422,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(50, "Phase", "P2", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_11b = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/option_on_timing__after_failure__system.xlsx",
          None,
          1,
@@ -436,7 +439,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(20, "Phase", "P2", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_11c = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/option_on_timing_v2__after_repair__system.xlsx",
          None,
          1,
@@ -453,7 +456,7 @@ class test_E2E_phases(unittest.TestCase):
         Result(0, "Phase", "P2", "*", "_MEAN_DURATION", tolerance=6),
     ]
     scenario_11d = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/option_on_timing_v2__never__system.xlsx",
          None,
          1,
@@ -477,7 +480,7 @@ class test_E2E_phases(unittest.TestCase):
                                "E_0_10", "C_0_12"]:
         expected_result_scenario_12_v1.append(Result(3, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
     scenario_12_v1 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version4_check_postpone_v1_system.xlsx",
          None,
          1,
@@ -500,7 +503,7 @@ class test_E2E_phases(unittest.TestCase):
                                "E_0_10", "C_0_12"]:
         expected_result_scenario_12_v2.append(Result(4, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
     scenario_12_v2 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version4_check_postpone_v2_system.xlsx",
          None,
          1,
@@ -523,7 +526,7 @@ class test_E2E_phases(unittest.TestCase):
                            "E_0_10", "C_0_12"]:
         expected_result_scenario_12_v3.append(Result(4, component_name, "*", "RUNNING", "_MEAN_OCCURRENCES"))
     scenario_12_v3 = \
-        ["./availsim4core/test/E2E/input/phases/simulation.xlsx",
+        [SIMULATION_FILEPATH,
          "./availsim4core/test/E2E/input/phases/version4_check_postpone_v3_system.xlsx",
          None,
          1,
@@ -583,7 +586,7 @@ class test_E2E_phases(unittest.TestCase):
             shutil.rmtree(output_folder)
 
         # Run the main process
-        main.start(simulation_file, system_file, sensitivity_file, output_folder)
+        main.start(simulation_file, system_file, output_folder, sensitivity_file)
 
         result_simulation_file_list = glob.glob(output_folder + "/*.xlsx")
         self.assertEqual(len(result_simulation_file_list), expected_number_file_result)
