@@ -1,10 +1,11 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 import copy
 import unittest
 
 from availsim4core.src.context.phase.phase import Phase
+from availsim4core.src.context.phase.phase_manager import PhaseManager
 from availsim4core.src.context.system.architecture_entry import ArchitectureEntry
 from availsim4core.src.context.system.children_logic.and_ import And
 from availsim4core.src.context.system.children_logic.children_logic import ChildrenLogic
@@ -20,6 +21,12 @@ from availsim4core.src.context.system.minimal_replaceable_unit import MinimalRep
 from availsim4core.src.context.system.probability_law.probability_law import ProbabilityLaw
 from availsim4core.src.context.system import sanity_check
 from availsim4core.src.context.system.system_template import SystemTemplate
+from availsim4core.src.reader.xlsx.system_template.architecture_sheet_reader import ArchitectureSheetReader
+from availsim4core.src.reader.xlsx.system_template.failure_mode_assignments_sheet_reader import FailureModesAssignmentSheetReader
+from availsim4core.src.reader.xlsx.system_template.failure_modes_sheet_reader import FailureModesSheetReader
+from availsim4core.src.reader.xlsx.system_template.inspection_sheet_reader import InspectionSheetReader
+from availsim4core.src.reader.xlsx.system_template.mru_sheet_reader import MinimalReplaceableUnitSheetReader
+from availsim4core.src.reader.xlsx.system_template.phases_sheet_reader import PhasesSheetReader
 from availsim4core.src.reader.xlsx.system_template_reader import SystemTemplateSheet, SystemTemplateReader
 
 
@@ -34,9 +41,7 @@ class test_ComponentFactory(unittest.TestCase):
                                               Status.FAILED,
                                               root_name)
 
-        NO_PHASE = Phase("NONE", ProbabilityLaw("", 0, False), False)
-        NO_PHASE.set_next_phase(NO_PHASE)
-        NO_PHASE.set_next_phase_if_failure(NO_PHASE)
+        NO_PHASE = PhaseManager.NO_PHASE
 
         expected_inspection = Inspection("inspection_test", 1, 2)
 
@@ -108,7 +113,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -155,7 +160,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -188,7 +193,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -238,7 +243,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -301,7 +306,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -358,7 +363,7 @@ class test_ComponentFactory(unittest.TestCase):
                                          [failure_mode_1],
                                          [],
                                          [],
-                                         None, 
+                                         None,
                                          set(),
                                          set(),
                                          None)
@@ -451,21 +456,21 @@ class test_ComponentFactory(unittest.TestCase):
             "ARCHITECTURE":{
                 0: {"COMPONENT_NAME": 'ROOT',
                     "COMPONENT_TYPE": 'COMPOUND',
-                    "COMPONENT_NUMBER": 1,
+                    "COMPONENT_NUMBER": "1",
                     "CHILDREN_NAME": 'ACCELERATORCONTROLS,ACCESSMANAGEMENT',####,BEAMLOSSES',
                     "CHILDREN_LOGIC": "AND",
                     "IN_MRU": 'none',
                     "TRIGGER_MRU": 'none'},
                 1: {"COMPONENT_NAME": 'ACCELERATORCONTROLS',
                     "COMPONENT_TYPE": 'basic',
-                    "COMPONENT_NUMBER": 2,
+                    "COMPONENT_NUMBER": "2",
                     "CHILDREN_NAME": 'none',
                     "CHILDREN_LOGIC": 'none',
                     "IN_MRU": 'LHC_MRU',
                     "TRIGGER_MRU": 'none'},
                 2: {"COMPONENT_NAME": 'ACCESSMANAGEMENT',
                     "COMPONENT_TYPE": 'basic',
-                    "COMPONENT_NUMBER": 1,
+                    "COMPONENT_NUMBER": "1",
                     "CHILDREN_NAME": 'none',
                     "CHILDREN_LOGIC": 'none',
                     "IN_MRU": 'none',
@@ -478,9 +483,9 @@ class test_ComponentFactory(unittest.TestCase):
             "FAILURE_MODES": {
                 0: {"FAILURE_MODE_NAME": 'ACCELERATORCONTROLSFAILURE',
                     "FAILURE_LAW": "EXP",
-                    "FAILURE_PARAMETERS": 300.0,
+                    "FAILURE_PARAMETERS": "300.0",
                     "REPAIR_LAW": "FIX",
-                    "REPAIR_PARAMETERS": 1.5436,
+                    "REPAIR_PARAMETERS": "1.5436",
                     "TYPE_OF_FAILURE": "DETECTABLE",
                     "HELD_BEFORE_REPAIR": "NEVER_HELD",
                     "INSPECTION_NAME": 'none',
@@ -490,11 +495,11 @@ class test_ComponentFactory(unittest.TestCase):
                     "HELD_AFTER_REPAIR":"NEVER_HELD"},
                 1: {"FAILURE_MODE_NAME": 'ACCESSMANAGEMENTFAILURE',
                     "FAILURE_LAW": "EXP",
-                    "FAILURE_PARAMETERS": 859.74,
+                    "FAILURE_PARAMETERS": "859.74",
                     "TYPE_OF_FAILURE": "DETECTABLE",
                     "HELD_BEFORE_REPAIR": "NEVER_HELD",
                     "REPAIR_LAW": "FIX",
-                    "REPAIR_PARAMETERS": 3.6167,
+                    "REPAIR_PARAMETERS": "3.6167",
                     "INSPECTION_NAME": 'INSPECT',
                     "PHASE_NAME": 'OPERATION',
                     "NEXT_PHASE_IF_FAILURE": 'none',
@@ -504,20 +509,20 @@ class test_ComponentFactory(unittest.TestCase):
             "MRU":{
                 0: {'MRU_NAME': 'LHC_MRU',
                     "MRU_LAW": "FIX",
-                    "MRU_PARAMETERS": 0.001,
+                    "MRU_PARAMETERS": "0.001",
                     "MRU_SCHEDULE": "IMMEDIATE",
                     "LOWEST_COMMON_ANCESTOR_SCOPE": 'ROOT',
                     "TRIGGERING_STATUS": 'FAILED'}
             },
             "INSPECTIONS":{
                 0: {"INSPECTION_NAME": 'INSPECT',
-                    "INSPECTION_PERIOD":5,
-                    "INSPECTION_DURATION": 2}
+                    "INSPECTION_PERIOD":"5",
+                    "INSPECTION_DURATION": "2"}
             },
             "PHASES":{
                 0: {"PHASE_NAME": 'OPERATION',
                     "PHASE_LAW": 'FIX',
-                    "PHASE_PARAMETERS": 1,
+                    "PHASE_PARAMETERS": "1",
                     "FIRST_PHASE":"True",
                     "NEXT_DEFAULT_PHASE":'OPERATION',
                     "NEXT_DEFAULT_PHASE_IF_FAILURE":'OPERATION'
@@ -529,24 +534,24 @@ class test_ComponentFactory(unittest.TestCase):
 
             # creating a system template
 
-            architecture_entry_list = SystemTemplateReader.generate_architecture_entry_list(
+            architecture_entry_list = ArchitectureSheetReader().generate_architecture_entry_list(
                 system_dictionary[SystemTemplateSheet.ARCHITECTURE])
 
-            mru_list = SystemTemplateReader.generate_mrus(
-                system_dictionary[SystemTemplateSheet.MINIMAL_REPLACEABLE_UNIT])
+            mru_list = MinimalReplaceableUnitSheetReader().generate_mrus(
+                system_dictionary[SystemTemplateSheet.MINIMAL_REPLACEABLE_UNIT], "")
 
-            inspections_list = SystemTemplateReader.generate_inspections(
+            inspections_list = InspectionSheetReader().generate_inspections(
                 system_dictionary[SystemTemplateSheet.INSPECTIONS])
 
-            phases_list = SystemTemplateReader.generate_phases(
+            phases_list = PhasesSheetReader().generate_phases(
                 system_dictionary[SystemTemplateSheet.PHASES])
 
-            failure_modes_list = SystemTemplateReader.generate_failure_modes(
+            failure_modes_list = FailureModesSheetReader().generate_failure_modes(
                 system_dictionary[SystemTemplateSheet.FAILURE_MODES],
                 inspections_list,
                 phases_list)
 
-            failure_mode_assignments_list = SystemTemplateReader.generate_failure_mode_assignments(
+            failure_mode_assignments_list = FailureModesAssignmentSheetReader().generate_failure_mode_assignments(
                 system_dictionary[SystemTemplateSheet.FAILURE_MODE_ASSIGNMENTS],
                 failure_modes_list)
 
@@ -570,44 +575,44 @@ class test_ComponentFactory(unittest.TestCase):
             return matching
 
         matching = comparing_a_dictionary_to_its_tree(default_dictionary)
-        self.assertEqual(matching,True)
+        self.assertTrue(matching)
 
         # modifying some entries but still matching dictionary and tree
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['ARCHITECTURE'][0]["COMPONENT_NAME"]="root"
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching,True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['ARCHITECTURE'][0]["CHILDREN_LOGIC"] = "and"
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['ARCHITECTURE'][0]["CHILDREN_LOGIC"] = " and "
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['FAILURE_MODES'][0]["FAILURE_MODE_NAME"]='AccELERATORCONTROLSFAILURE'
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching,True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['FAILURE_MODES'][0]["FAILURE_MODE_NAME"]=' ACCELERATORCONTROLSFAILURE'
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching,True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['ARCHITECTURE'][1]["COMPONENT_NUMBER"] = ' 2'
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, True)
+        self.assertTrue(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
-        modified_dictionary['ARCHITECTURE'][1]["COMPONENT_NUMBER"] = 2.
+        modified_dictionary['ARCHITECTURE'][1]["COMPONENT_NUMBER"] = "2 "
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, True)
+        self.assertTrue(matching)
 
         # modifying some entries, dictionary and tree don't match
 
@@ -615,20 +620,20 @@ class test_ComponentFactory(unittest.TestCase):
         modified_dictionary['ARCHITECTURE'][3] = \
             {"COMPONENT_NAME": 'DUMMY_COMPONENT_NOT_USED',
              "COMPONENT_TYPE": 'basic',
-             "COMPONENT_NUMBER": 1,
+             "COMPONENT_NUMBER": "1",
              "CHILDREN_NAME": 'none',
              "CHILDREN_LOGIC": 'none',
              "IN_MRU": 'none',
              "TRIGGER_MRU": 'LHC_MRU'}
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, False)
+        self.assertFalse(matching)
 
         modified_dictionary = copy.deepcopy(default_dictionary)
         modified_dictionary['FAILURE_MODE_ASSIGNMENTS'] = {
             0: {"COMPONENT_NAME": 'ACCELERATORCONTROLS', "FAILURE_MODE_NAME": 'ACCELERATORCONTROLSFAILURE'}
         }
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, False)
+        self.assertFalse(matching)
 
         # modifying some entries, dictionary and tree don't match explicitly but still the test is passed
         # the phase added "DOWNTIME" is defined but never explicitly used in the input file, still it's present in the
@@ -638,10 +643,10 @@ class test_ComponentFactory(unittest.TestCase):
         modified_dictionary['PHASES'][1] = \
             {"PHASE_NAME": 'DOWNTIME',
              "PHASE_LAW": 'FIX',
-             "PHASE_PARAMETERS": 1,
-             "FIRST_PHASE": "True",
+             "PHASE_PARAMETERS": "1",
+             "FIRST_PHASE": "False",
              "NEXT_DEFAULT_PHASE": 'OPERATION',
              "NEXT_DEFAULT_PHASE_IF_FAILURE": 'OPERATION'
              }
         matching = comparing_a_dictionary_to_its_tree(modified_dictionary)
-        self.assertEqual(matching, True)
\ No newline at end of file
+        self.assertTrue(matching)
