@@ -1,5 +1,5 @@
 # SPDX-License-Identifier: GPL-3.0-only
-# (C) Copyright CERN 2021. All rights not expressly granted are reserved. 
+# (C) Copyright CERN 2021. All rights not expressly granted are reserved.
 
 import unittest
 from unittest.mock import patch
@@ -12,8 +12,10 @@ from availsim4core.src.context.system.failure_mode_assignments import FailureMod
 from availsim4core.src.context.system.probability_law.deterministic_law import DeterministicLaw
 from availsim4core.src.context.system.probability_law.exponential_law import ExponentialLaw
 from availsim4core.src.context.system.system_template import SystemTemplate
-from availsim4core.src.reader.xlsx.sensitivity_analysis_reader import SensitivityAnalysisReader
+from availsim4core.src.reader.xlsx import xlsx_utils
 from availsim4core.src.sensitivity_analysis.sensitivity_analysis import SensitivityAnalysis
+from availsim4core.src.reader.xlsx.sensitivity_analysis_reader import SensitivityAnalysisReader
+from availsim4core.src.sensitivity_analysis.sensitivity_analysis import OverlappingSeedsError, SensitivityAnalysis
 from availsim4core.src.sensitivity_analysis.system_modifier.system_modifier import SystemModifier
 from availsim4core.src.sensitivity_analysis.system_modifier.system_modifier_combination import SystemModifierCombination
 from availsim4core.src.simulation.monte_carlo import MonteCarlo
@@ -52,13 +54,13 @@ class test_SensitivityAnalysis(unittest.TestCase):
                                                  [failure_mode],
                                                  mru_list,
                                                  inspection_list,
-                                                 phase_manager, 
+                                                 phase_manager,
                                                  set(),
                                                  set(),
                                                  None)
 
         # Analysis 1 -> SENSITIVITY_SEED_1
-        analysis_simulation_1 = MonteCarlo(1000, 1000, 2., 120, SENSITIVITY_SEED_1, ['SUMMARY'], 1)
+        analysis_simulation_1 = MonteCarlo(10, 10, 2., 120, SENSITIVITY_SEED_1, ['SUMMARY'], 1)
 
         architecture_entry_list = [ArchitectureEntry("DUMB", "COMPOUND", 1, ['DUMBER'], "AND", [], []),
                                    ArchitectureEntry("DUMBER", "BASIC", 1, [], '', [], [])]
@@ -91,7 +93,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
         analysis_1 = Analysis(0, analysis_system_template_1, analysis_simulation_1)
 
         # Analysis 2 -> SENSITIVITY_SEED_2
-        analysis_simulation_2 = MonteCarlo(1000, 1000, 2., 120, SENSITIVITY_SEED_2, ['SUMMARY'], 1)
+        analysis_simulation_2 = MonteCarlo(10, 10, 2., 120, SENSITIVITY_SEED_2, ['SUMMARY'], 1)
 
         architecture_entry_list = [ArchitectureEntry("DUMB", "COMPOUND", 1, ['DUMBER'], "AND", [], []),
                                    ArchitectureEntry("DUMBER", "BASIC", 1, [], '', [], [])]
@@ -132,9 +134,15 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
-            sensitivity_analysis = SensitivityAnalysis(initial_simulation,
-                                                       initial_system_template)
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
+            # Making sure that the method throws OverlappingSeedsError
+            sensitivity_analysis = SensitivityAnalysis(initial_simulation, initial_system_template)
+            self.assertRaises(OverlappingSeedsError, sensitivity_analysis.generate_analysis_list, "fake_path")
+
+            # Changing the number of iterations per instance
+            initial_simulation.minimum_number_of_simulations = 10
+            initial_simulation.maximum_number_of_simulations = 10
+            sensitivity_analysis = SensitivityAnalysis(initial_simulation, initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
 
         self.assertEqual(expected_result, result)
@@ -202,7 +210,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
                                                     [failure_mode],
                                                     mru_list,
                                                     inspection_list,
-                                                    phase_manager, 
+                                                    phase_manager,
                                                     set(),
                                                     set(),
                                                     None)
@@ -250,7 +258,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -368,7 +376,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -382,7 +390,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
                                                COMPONENT_NUMBER,
                                                CHILDREN_LOGIC):
 
-            initial_simulation = MonteCarlo(1000, 1000, 2., 120, SEED, ['SUMMARY'], 1)
+            initial_simulation = MonteCarlo(1, 1, 2., 120, SEED, ['SUMMARY'], 1)
 
             architecture_entry_list = [ArchitectureEntry("DUMB", "COMPOUND", 1, ['DUMBER'], CHILDREN_LOGIC, [], []),
                                        ArchitectureEntry("DUMBER", "BASIC", COMPONENT_NUMBER, [], '', [], [])]
@@ -555,7 +563,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -673,7 +681,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -743,7 +751,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
                                                     [failure_mode],
                                                     mru_list,
                                                     inspection_list,
-                                                    phase_manager, 
+                                                    phase_manager,
                                                     set(),
                                                     set(),
                                                     None)
@@ -791,7 +799,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -982,7 +990,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -1108,7 +1116,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
@@ -1200,7 +1208,7 @@ class test_SensitivityAnalysis(unittest.TestCase):
             }
         }
 
-        with patch.object(SensitivityAnalysisReader, "read", return_value=sensitivity_analysis_dictionary):
+        with patch.object(xlsx_utils, "read", return_value=sensitivity_analysis_dictionary):
             sensitivity_analysis = SensitivityAnalysis(initial_simulation,
                                                        initial_system_template)
             result = sensitivity_analysis.generate_analysis_list("fake_path")
